@@ -1,7 +1,11 @@
+import os
+from pathlib import Path
 import click
-from stochasticx.auth.auth import Stochastic
 from getpass import getpass
 
+from stochasticx.auth.auth import Stochastic
+from stochasticx.constants.urls import TOKEN_AUTH_PATH
+
 stochastic = Stochastic()
 
 @click.command(name="login")
@@ -19,6 +23,16 @@ def login(username, password):
     click.secho("[+] Login successfully", fg="green", bold=True)
 
 
+@click.command(name="logout")
+def logout():
+    token_path = Path(TOKEN_AUTH_PATH).resolve()
+
+    if token_path.exists():
+        os.remove(token_path)
+
+    click.secho("[+] Logged out successfully", fg="green", bold=True)
+
+
 @click.group(name="me")
 def me():
     pass
