@@ -1,5 +1,9 @@
+from dataclasses import dataclass, field, asdict
 import requests
 from datetime import datetime
+import click
+import sys
+from typing import Dict
 
 from stochasticx.constants.urls import (
     INFERENCE_URL, 
@@ -11,11 +15,209 @@ from stochasticx.utils.auth_utils import AuthUtils
 from stochasticx.models.models import OptimizedModel, Models
 from stochasticx.utils.logging import configure_logger
 from stochasticx.utils.parse_utils import parse_date
-import click
-import sys
+
 
 logger = configure_logger(__name__)
 
+class LocalDeploymentsClient:
+    
+    @staticmethod
+    def get_deployments(fmt="table"):
+        response = requests.get("http://127.0.0.1:5051/models")
+        response.raise_for_status()
+
+        models = response.json()
+        model_results = []
+
+        for model in models:
+            model_results.append(LocalDeployment(
+                id=model.get("id"),
+                model_name=model.get("model_name"),
+                type=model.get("type"),
+                cuda=model.get("cuda"),
+                task_type=model.get("task_type"),
+                user_params=model.get("user_params")
+            ))
+
+        if fmt == "table":
+            columns = []
+            values = []
+            
+            if len(model_results) > 0:
+                columns, _ = model_results[0].to_table()
+                
+            for model in model_results:
+                _, vals = model.to_table()
+                values.append(vals)
+                
+            return columns, values
+        else:
+            return model_results
+
+    @staticmethod
+    def get_deployment_by_id(id):
+        deployments = LocalDeploymentsClient.get_deployments(fmt=None)
+
+        for deployment in deployments:
+            if deployment.id == id:
+                return deployment
+
+        return None
+
+    @staticmethod
+    def delete_deployment(model_type, model_name):
+        response = requests.delete("http://127.0.0.1:5051/model/{}/{}".format(
+            model_type,
+            model_name
+        ))
+        response.raise_for_status()
+
+
+@dataclass
+class LocalDeployment:
+    model_name: str
+    type: str
+    cuda: bool
+    task_type: str
+    user_params: Dict
+    id: str = None
+
+    def to_table(self):
+        columns = [
+            "Model ID",
+            "Model name",
+            "Model type",
+            "CUDA",
+            "Task type",
+            "User params"
+        ]
+
+        values = [
+            str(self.id),
+            self.model_name,
+            self.type,
+            str(self.cuda),
+            self.task_type,
+            str(self.user_params)
+        ]
+
+        return columns, values
+    
+    
+@dataclass
+class LocalSequenceClassificationDeployment(LocalDeployment):
+    task_type: str = "sequence_classification"
+    user_params: Dict = field(default_factory=lambda: {
+        "max_batch_size":8,
+        "max_seq_length":128
+    })
+    
+    def start_deployment(self):
+        response = requests.post(
+            "http://127.0.0.1:5051/model",
+            json=asdict(self)
+        )
+        
+        response.raise_for_status()
+
+
+@dataclass
+class LocalQuestionAnsweringDeployment(LocalDeployment):
+    task_type: str = "question_answering"
+    user_params: Dict = field(default_factory=lambda: {
+        "max_batch_size":8,
+        "max_seq_length":256,
+        "stride":30
+    })
+    
+    def start_deployment(self):
+        response = requests.post(
+            "http://127.0.0.1:5051/model",
+            json=asdict(self)
+        )
+        
+        response.raise_for_status()
+
+
+@dataclass
+class LocalTokenClassificationDeployment(LocalDeployment):
+    task_type: str = "token_classification"
+    user_params: Dict = field(default_factory=lambda: {
+        "max_seq_length": 256,
+	    "label_all_tokens": False
+    })
+    
+    def start_deployment(self):
+        response = requests.post(
+            "http://127.0.0.1:5051",
+            json=asdict(self)
+        )
+        
+        response.raise_for_status()
+
+
+@dataclass
+class LocalTranslationDeployment(LocalDeployment):
+    task_type: str = "translation"
+    user_params: Dict = field(default_factory=lambda: {
+        "max_source_length": 256,
+        "max_target_length": 256,
+        "src_lang": "en",
+        "tgt_lang": "es",
+        "pad_to_max_length": False,
+        "num_beams": 4,
+        "ignore_pad_token_for_loss": True,
+        "source_prefix": "",
+        "forced_bos_token": None
+    })
+    
+    def start_deployment(self):
+        response = requests.post(
+            "http://127.0.0.1:5051/model",
+            json=asdict(self)
+        )
+        
+        response.raise_for_status()
+
+
+@dataclass
+class LocalSummarizationDeployment(LocalDeployment):
+    task_type: str = "summarization"
+    user_params: Dict = field(default_factory=lambda: {
+        "max_source_length": 256,
+        "max_target_length": 64,
+        "lang": "en",
+        "pad_to_max_length": False,
+        "num_beams": 4,
+        "ignore_pad_token_for_loss": True,
+        "source_prefix": "",
+        "forced_bos_token": None
+    })
+    
+    def start_deployment(self):
+        response = requests.post(
+            "http://127.0.0.1:5051/model",
+            json=asdict(self)
+        )
+        
+        response.raise_for_status()
+
+
+@dataclass
+class LocalTextGenerationDeployment(LocalDeployment):
+    task_type: str = "text_generation"
+    user_params: Dict = field(default_factory=lambda: {
+        "block_size": 256
+    })
+    
+    def start_deployment(self):
+        response = requests.post(
+            "http://127.0.0.1:5051/model",
+            json=asdict(self)
+        )
+        
+        response.raise_for_status()
+
 
 class InferenceTaskType:
     def __init__(self):
