@@ -1,5 +1,5 @@
 import subprocess
-import psutil
+#import psutil
 
 def is_nvidia_gpu_available():
    try:
@@ -8,12 +8,14 @@ def is_nvidia_gpu_available():
    except Exception:
       return False
 
+"""
 def get_cpu_info():
     cpu_cores= psutil.cpu_count()
     mem = psutil.virtual_memory() #(total,available,percent,used,free,...)
     
     return {"CPU_cores":cpu_cores,
             "Memory": mem[1]}
+"""
 
 def get_gpu_info():
     gpu_name_map = {"Tesla T4":"T4"}
